@@ -11,8 +11,8 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; see the file COPYING.  If not, write to
-// the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-// Boston, MA 02111-1307, USA.
+// the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+// Boston, MA 02110-1301, USA.
 
 #include <errno.h>
 
@@ -103,7 +103,7 @@ Atlantik::Atlantik ()
 
 	// Toolbar: Game
 //	KStdGameAction::gameNew(this, SLOT(slotNewGame()), actionCollection(), "game_new");
-	m_showEventLog = new KAction(i18n("Show Event &Log"), "atlantik_showeventlog", CTRL+Key_L, this, SLOT(showEventLog()), actionCollection(), "showeventlog");
+        m_showEventLog = new KAction(i18n("Show Event &Log")/*, "atlantik_showeventlog"*/, CTRL+Key_L, this, SLOT(showEventLog()), actionCollection(), "showeventlog");
 	KStdGameAction::quit(kapp, SLOT(closeAllWindows()), actionCollection(), "game_quit");
 
 	// Toolbar: Settings
@@ -138,11 +138,11 @@ Atlantik::Atlantik ()
 	m_auctionEstate->setEnabled(false);
 	m_endTurn = KStdGameAction::endTurn(this, SIGNAL(endTurn()), actionCollection());
 	m_endTurn->setEnabled(false);
-	m_jailCard = new KAction(i18n("Use Card to Leave Jail"), "atlantik_move_jail_card", 0, this, SIGNAL(jailCard()), actionCollection(), "move_jailcard");
+        m_jailCard = new KAction(i18n("Use Card to Leave Jail")/*, "atlantik_move_jail_card"*/, 0, this, SIGNAL(jailCard()), actionCollection(), "move_jailcard");
 	m_jailCard->setEnabled(false);
 	m_jailPay = new KAction(i18n("&Pay to Leave Jail"), "jail_pay", CTRL+Key_P, this, SIGNAL(jailPay()), actionCollection(), "move_jailpay");
 	m_jailPay->setEnabled(false);
-	m_jailRoll = new KAction(i18n("Roll to Leave &Jail"), "atlantik_move_jail_roll", CTRL+Key_J, this, SIGNAL(jailRoll()), actionCollection(), "move_jailroll");
+        m_jailRoll = new KAction(i18n("Roll to Leave &Jail")/*, "atlantik_move_jail_roll"*/, CTRL+Key_J, this, SIGNAL(jailRoll()), actionCollection(), "move_jailroll");
 	m_jailRoll->setEnabled(false);
 
 	// Mix code and XML into GUI
@@ -221,6 +221,7 @@ void Atlantik::readConfig()
 	// Personalization configuration
 	config->setGroup("Personalization");
 	m_config.playerName = config->readEntry("PlayerName", "Atlantik");
+	m_config.playerImage = config->readEntry("PlayerImage", "cube.png");
 
 	// Board configuration
 	config->setGroup("Board");
@@ -256,7 +257,7 @@ void Atlantik::newPlayer(Player *player)
 	connect(player, SIGNAL(gainedTurn()), this, SLOT(gainedTurn()));
 	connect(player, SIGNAL(changed(Player *)), m_board, SLOT(playerChanged(Player *)));
 
-	KNotifyClient::event(this->winId(), "newplayer");
+	KNotifyClient::event(winId(), "newplayer");
 }
 
 void Atlantik::newEstate(Estate *estate)
@@ -525,6 +526,13 @@ void Atlantik::slotUpdateConfig()
 		m_atlantikNetwork->setName(optStr);
 	}
 
+	optStr = m_configDialog->playerImage();
+	if (m_config.playerImage != optStr)
+	{
+		m_config.playerImage = optStr;
+		m_atlantikNetwork->setImage(optStr);
+	}
+
 	optBool = m_configDialog->indicateUnowned();
 	if (m_config.indicateUnowned != optBool)
 	{
@@ -582,6 +590,7 @@ void Atlantik::slotUpdateConfig()
 
 	config->setGroup("Personalization");
 	config->writeEntry("PlayerName", m_config.playerName);
+	config->writeEntry("PlayerImage", m_config.playerImage);
 
 	config->setGroup("Board");
 	config->writeEntry("IndicateUnowned", m_config.indicateUnowned);
@@ -631,7 +640,7 @@ void Atlantik::slotMsgChat(QString player, QString msg)
 	}
 	else
 		serverMsgsAppend(player + ": " + msg);
-	KNotifyClient::event(this->winId(), "chat");
+	KNotifyClient::event(winId(), "chat");
 }
 
 void Atlantik::serverMsgsAppend(QString msg)
@@ -702,7 +711,7 @@ void Atlantik::playerChanged(Player *player)
 
 void Atlantik::gainedTurn()
 {
-	KNotifyClient::event(this->winId(), "gainedturn");
+	KNotifyClient::event(winId(), "gainedturn", i18n("It is your turn now.") );
 }
 
 void Atlantik::initEventLog()
@@ -775,6 +784,7 @@ void Atlantik::clientCookie(QString cookie)
 void Atlantik::sendHandshake()
 {
 	m_atlantikNetwork->setName(m_config.playerName);
+	m_atlantikNetwork->setImage(m_config.playerImage);
 
 	// Check command-line args to see if we need to auto-join
 	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
@@ -830,9 +840,9 @@ void Atlantik::closeEvent(QCloseEvent *e)
 
 	int result = KMessageBox::Yes;
 	if ( gameSelf && !playerSelf->isBankrupt() && m_runningGame )
-		result = KMessageBox::warningYesNo( this, i18n("You are currently part of an active game. Are you sure you want to close Atlantik? If you do, you forfeit the game."), i18n("Close & Forfeit?") );
+		result = KMessageBox::warningContinueCancel( this, i18n("You are currently part of an active game. Are you sure you want to close Atlantik? If you do, you forfeit the game."), i18n("Close & Forfeit?"), i18n("Close && Forfeit") );
 
-	if ( result == KMessageBox::Yes )
+	if ( result == KMessageBox::Continue )
 	{
 		if ( m_atlantikNetwork )
 			m_atlantikNetwork->leaveGame();
