@@ -2,6 +2,7 @@
 #define COMMON_INTER_H
 
 #include <kexthighscore.h>
+#include <kdemacros.h>
 
 #include "lib/mp_simple_interface.h"
 #include "base/inter.h"
@@ -11,7 +12,7 @@
 
 class Field;
 
-class Interface : public MPSimpleInterface, public BaseInterface
+class KDE_EXPORT Interface : public MPSimpleInterface, public BaseInterface
 {
     Q_OBJECT
 public:
